LogicalOperator - agents API reference (0.0.10)

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# LogicalOperator

class inmydata.StructuredData.LogicalOperator(value)

  Bases: `Enum`

  Enum representing a logical operator for combining conditions in AIDataFilter.

  And

    Represents the logical AND operator.

  Or

    Represents the logical OR operator.

  AndNot

    Represents the logical AND NOT operator.

  And = 0
  AndNot = 2
  Or = 1